Version 0.4.1
-------------
- Update precommit hooks mypy and black versions

Version 0.4.0
-------------
- Support for extracting variable length MWE given a user pattern of POS tags.


Version 0.3.7
-------------
- Change newline encoding.
- To support multiline in GitHub release body.


Version 0.3.6
-------------
- Test description.
- Test description2.
- Test description3.
- Test description4.

Version 0.3.5
-------------
- Test description.
- Test description2.

Version 0.3.4
-------------
- Update awk sed parser to correctly read release body. 

Version 0.3.3
-------------
- Fix missing multiline description in GitHub release using printf.

Version 0.3.2
-------------
- Fix missing multiline description in GitHub release.

Version 0.3.1
-------------
- Add action for CD.
- Publish to PyPi and GitHub Releases on bump version.
- Improve the CD workflow to ensure checks are passed and the merge is successful.
- Check for release notes, otherwise do not publish. 

Version 0.2.4
-------------
- Improve MWE functionalities.
- Fix fasttext issues.
- Remove support for Python 11 (for now).

Version 0.2.3
-------------
- Make POS wordclouds configurable.
- Remove pos wordclouds and distplots as fields, and allow access to them via function call, for an improved data encapsulation.

Version 0.2.2
-------------
- Upgrade wordcloud version to latest to avoid build failure.


Version 0.2.1
-------------
- Upgrade pandas and scikit-learn versions

Version 0.2.0
-------------

- Major refactoring with a semi-stable features (see below) and their documentations.
- Exploratory Data Analysis.
- Doc level Label Analysis.
- Clustering.
- Preprocessing functions.
- Partial MWEs.
- Tets.


Version 0.1.0
-------------

- Initial release with major Exploratory Data Analysis, MWEs, and Preprocessing features.
- Initial documentations.
